@@ -44,6 +44,7 @@ struct field_s {
     void (*from_hash)(element_ptr, int len, void *data);
     int (*is1)(element_ptr);
     int (*is0)(element_ptr);
+    int (*sign)(element_ptr); //satisfies sign(x) = -sign(-x)
     int (*is_sqr)(element_ptr);
     void (*sqrt)(element_ptr, element_ptr);
     int (*to_bytes)(unsigned char *data, element_ptr);
@@ -172,6 +173,11 @@ static inline int element_is_sqr(element_ptr a)
     return a->field->is_sqr(a);
 }
 
+static inline int element_sign(element_ptr a)
+{
+    return a->field->sign(a);
+}
+
 static inline void element_sqrt(element_ptr a, element_ptr b)
 {
     a->field->sqrt(a, b);
